# Critical Issues and Fixes (absorbed)

See [docs/_archive/CRITICAL_ISSUES_AND_FIXES.md](../_archive/CRITICAL_ISSUES_AND_FIXES.md). Current status: [REF_22_PROJECT.md](../REF_22_PROJECT.md), [REF_35_REVIEW.md](../REF_35_REVIEW.md).
